# The Editor’s UI Data

Namespace: `core/edit-post`.

## Selectors

<!-- START TOKEN(Autogenerated selectors|../../../packages/edit-post/src/store/selectors.js) -->

### areMetaBoxesInitialized

Returns true if meta boxes are initialized.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether meta boxes are initialized.

### getActiveGeneralSidebarName

Returns the current active general sidebar name, or null if there is no
general sidebar active. The active general sidebar is a unique name to
identify either an editor or plugin sidebar.

Examples:

-   `edit-post/document`
-   `my-plugin/insert-image-sidebar`

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `?string`: Active general sidebar name.

### getActiveMetaBoxLocations

Returns an array of active meta box locations.

_Parameters_

-   _state_ `Object`: Post editor state.

_Returns_

-   `string[]`: Active meta box locations.

### getAllMetaBoxes

Returns the list of all the available meta boxes.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Array`: List of meta boxes.

### getEditedPostTemplate

Retrieves the template of the currently edited post.

_Returns_

-   `Object?`: Post Template.

### getEditorMode

Returns the current editing mode.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `string`: Editing mode.

### getHiddenBlockTypes

Returns an array of blocks that are hidden.

_Returns_

-   `Array`: A list of the hidden block types

### getMetaBoxesPerLocation

Returns the list of all the available meta boxes for a given location.

_Parameters_

-   _state_ `Object`: Global application state.
-   _location_ `string`: Meta box location to test.

_Returns_

-   `?Array`: List of meta boxes.

### getPreference

_Parameters_

-   _state_ `Object`: Global application state.
-   _preferenceKey_ `string`: Preference Key.
-   _defaultValue_ `*`: Default Value.

_Returns_

-   `*`: Preference Value.

### getPreferences

Returns the preferences (these preferences are persisted locally).

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `Object`: Preferences Object.

### hasMetaBoxes

Returns true if the post is using Meta Boxes

_Parameters_

-   _state_ `Object`: Global application state

_Returns_

-   `boolean`: Whether there are metaboxes or not.

### isEditingTemplate

Returns true if the template editing mode is enabled.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether we're editing the template.

### isEditorPanelEnabled

Returns true if the given panel is enabled, or false otherwise. Panels are
enabled by default.

_Parameters_

-   _state_ `Object`: Global application state.
-   _panelName_ `string`: A string that identifies the panel.

_Returns_

-   `boolean`: Whether or not the panel is enabled.

### isEditorPanelOpened

Returns true if the given panel is open, or false otherwise. Panels are
closed by default.

_Parameters_

-   _state_ `Object`: Global application state.
-   _panelName_ `string`: A string that identifies the panel.

_Returns_

-   `boolean`: Whether or not the panel is open.

### isEditorPanelRemoved

Returns true if the given panel was programmatically removed, or false otherwise.
All panels are not removed by default.

_Parameters_

-   _state_ `Object`: Global application state.
-   _panelName_ `string`: A string that identifies the panel.

_Returns_

-   `boolean`: Whether or not the panel is removed.

### isEditorSidebarOpened

Returns true if the editor sidebar is opened.

_Parameters_

-   _state_ `Object`: Global application state

_Returns_

-   `boolean`: Whether the editor sidebar is opened.

### isFeatureActive

Returns whether the given feature is enabled or not.

_Parameters_

-   _state_ `Object`: Global application state.
-   _feature_ `string`: Feature slug.

_Returns_

-   `boolean`: Is active.

### isInserterOpened

Returns true if the inserter is opened.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the inserter is opened.

### isListViewOpened

Returns true if the list view is opened.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the list view is opened.

### isMetaBoxLocationActive

Returns true if there is an active meta box in the given location, or false
otherwise.

_Parameters_

-   _state_ `Object`: Post editor state.
-   _location_ `string`: Meta box location to test.

_Returns_

-   `boolean`: Whether the meta box location is active.

### isMetaBoxLocationVisible

Returns true if a metabox location is active and visible

_Parameters_

-   _state_ `Object`: Post editor state.
-   _location_ `string`: Meta box location to test.

_Returns_

-   `boolean`: Whether the meta box location is active and visible.

### isModalActive

Returns true if a modal is active, or false otherwise.

_Parameters_

-   _state_ `Object`: Global application state.
-   _modalName_ `string`: A string that uniquely identifies the modal.

_Returns_

-   `boolean`: Whether the modal is active.

### isPluginItemPinned

Returns true if the plugin item is pinned to the header.
When the value is not set it defaults to true.

_Parameters_

-   _state_ `Object`: Global application state.
-   _pluginName_ `string`: Plugin item name.

_Returns_

-   `boolean`: Whether the plugin item is pinned.

### isPluginSidebarOpened

Returns true if the plugin sidebar is opened.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the plugin sidebar is opened.

### isPublishSidebarOpened

Returns true if the publish sidebar is opened.

_Parameters_

-   _state_ `Object`: Global application state

_Returns_

-   `boolean`: Whether the publish sidebar is open.

### isSavingMetaBoxes

Returns true if the Meta Boxes are being saved.

_Parameters_

-   _state_ `Object`: Global application state.

_Returns_

-   `boolean`: Whether the metaboxes are being saved.

<!-- END TOKEN(Autogenerated selectors|../../../packages/edit-post/src/store/selectors.js) -->

## Actions

<!-- START TOKEN(Autogenerated actions|../../../packages/edit-post/src/store/actions.js) -->

### closeGeneralSidebar

Returns an action object signalling that the user closed the sidebar.

### closeModal

Returns an action object signalling that the user closed a modal.

_Returns_

-   `Object`: Action object.

### closePublishSidebar

Returns an action object used in signalling that the user closed the
publish sidebar.

_Returns_

-   `Object`: Action object.

### hideBlockTypes

Update the provided block types to be hidden.

_Parameters_

-   _blockNames_ `string[]`: Names of block types to hide.

### initializeMetaBoxes

Initializes WordPress `postboxes` script and the logic for saving meta boxes.

### metaBoxUpdatesFailure

Returns an action object used to signal a failed meta box update.

_Returns_

-   `Object`: Action object.

### metaBoxUpdatesSuccess

Returns an action object used to signal a successful meta box update.

_Returns_

-   `Object`: Action object.

### openGeneralSidebar

Returns an action object used in signalling that the user opened an editor sidebar.

_Parameters_

-   _name_ `?string`: Sidebar name to be opened.

### openModal

Returns an action object used in signalling that the user opened a modal.

_Parameters_

-   _name_ `string`: A string that uniquely identifies the modal.

_Returns_

-   `Object`: Action object.

### openPublishSidebar

Returns an action object used in signalling that the user opened the publish
sidebar.

_Returns_

-   `Object`: Action object

### removeEditorPanel

Returns an action object used to remove a panel from the editor.

_Parameters_

-   _panelName_ `string`: A string that identifies the panel to remove.

_Returns_

-   `Object`: Action object.

### requestMetaBoxUpdates

Update a metabox.

### setAvailableMetaBoxesPerLocation

Stores info about which Meta boxes are available in which location.

_Parameters_

-   _metaBoxesPerLocation_ `Object`: Meta boxes per location.

### setIsEditingTemplate

Returns an action object used to switch to template editing.

_Parameters_

-   _value_ `boolean`: Is editing template.

_Returns_

-   `Object`: Action object.

### setIsInserterOpened

Returns an action object used to open/close the inserter.

_Parameters_

-   _value_ `boolean|Object`: Whether the inserter should be opened (true) or closed (false). To specify an insertion point, use an object.
-   _value.rootClientId_ `string`: The root client ID to insert at.
-   _value.insertionIndex_ `number`: The index to insert at.

_Returns_

-   `Object`: Action object.

### setIsListViewOpened

Returns an action object used to open/close the list view.

_Parameters_

-   _isOpen_ `boolean`: A boolean representing whether the list view should be opened or closed.

_Returns_

-   `Object`: Action object.

### showBlockTypes

Update the provided block types to be visible.

_Parameters_

-   _blockNames_ `string[]`: Names of block types to show.

### switchEditorMode

Triggers an action used to switch editor mode.

_Parameters_

-   _mode_ `string`: The editor mode.

### toggleEditorPanelEnabled

Returns an action object used to enable or disable a panel in the editor.

_Parameters_

-   _panelName_ `string`: A string that identifies the panel to enable or disable.

_Returns_

-   `Object`: Action object.

### toggleEditorPanelOpened

Opens a closed panel and closes an open panel.

_Parameters_

-   _panelName_ `string`: A string that identifies the panel to open or close.

### toggleFeature

Triggers an action used to toggle a feature flag.

_Parameters_

-   _feature_ `string`: Feature name.

### togglePinnedPluginItem

Triggers an action object used to toggle a plugin name flag.

_Parameters_

-   _pluginName_ `string`: Plugin name.

### togglePublishSidebar

Returns an action object used in signalling that the user toggles the publish sidebar.

_Returns_

-   `Object`: Action object

### updatePreferredStyleVariations

Returns an action object used in signaling that a style should be auto-applied when a block is created.

_Parameters_

-   _blockName_ `string`: Name of the block.
-   _blockStyle_ `?string`: Name of the style that should be auto applied. If undefined, the "auto apply" setting of the block is removed.

<!-- END TOKEN(Autogenerated actions|../../../packages/edit-post/src/store/actions.js) -->
